{
  site.hosts = {
    switch-a1 = {
      role = "switch";
      model = "TL-SG3210";
      location = "Saal A";
      interfaces = { mgmt.type = "phys"; };

      links = {
        switch-a2.ports = [ "7" ];
        priv25.ports = [ "2" "3" "4" "5" ];
        priv31.ports = [ "6" ];
        pub.ports = [ "8" ];
        iso4.ports = [ "1" ];
      };
    };
    switch-a2 = {
      role = "switch";
      model = "dumb";
      location = "Saal A";

      links = {
        switch-c1.ports = [ "1" ];
        switch-a1.ports = [ "2" ];
        ap44.ports = [ "10" ];
        ap45.ports = [ "11" ];
        ap46.ports = [ "12" ];
        ap47.ports = [ "13" ];
        ap48.ports = [ "14" ];
        ap49.ports = [ "15" ];
        ap50.ports = [ "16" ];
        ap52.ports = [ "17" ];
      };
    };

    switch-b1 = {
      role = "switch";
      model = "linksys-srw2048";
      location = "Haus B Souterrain";
      interfaces = { mgmt.type = "phys"; };

      # Ports 1-19 ungerade oben
      # Ports 2-20 gerade unten
      # (15, 16 gehen aktuell nach Haus A)
      # Ports 21-24 unten seitlich (optional optisch)
      # Port 7 geht aktuell nach Turm C Erdgeschoss und dadurch zur Ecce
      links = {
        ap23.ports = [ "g10" ];
        ap8.ports = [ "g16" ];
        c3d2.ports = [
          # Leon's NAS
          "g23"
          # dump-dvb server
          "g48"
        ];
        iso1.ports = [ "g2" ];
        iso2.ports = [ "g3" ];
        iso3.ports = [ "g4" ];
        mgmt.ports = [ "g1" ];
        serv.ports = [
          "g22"
          # hydra
          "g47"
        ];
        # server1 had g46,g47,g48 too but this switch has too few
        # port-channel groups
        server1.ports = [ "g24" ];
        server2 = {
          group = "1";
          ports = [ "g12" "g38" "g39" "g40" ];
        };
        server5 = {
          group = "6";
          ports = [ "g17" "g18" "g19" "g20" ];
        };
        server6 = {
          group = "8";
          ports = [ "g5" "g6" "g7" "g8" ];
        };
        server7 = {
          group = "7";
          ports = [ "g9" "g11" "g14" "g15" ];
        };
        server8 = {
          group = "5";
          ports = [ "g35" "g36" "g37" "g13" ];
        };
        switch-b2 = {
          group = "3";
          ports = [ "g25" "g26" "g27" "g28" ];
        };
        switch-c1 = {
          group = "2";
          ports = [ "g29" "g30" "g31" "g32" ];
        };
        switch-c3d2-main = {
          group = "4";
          ports = [ "g41" "g42" "g43" "g44" ];
        };
        switch-d1.ports = [ "g34" ];
      };
    };
    switch-b2 = {
      role = "switch";
      model = "3com-4200G";
      location = "Haus B Souterrain";
      interfaces = { mgmt.type = "phys"; };

      links = {
        ap1.ports = [ "GigabitEthernet 1/0/8" ];
        ap11.ports = [ "GigabitEthernet 1/0/10" ];
        ap15.ports = [ "GigabitEthernet 1/0/12" ];
        ap18.ports = [ "GigabitEthernet 1/0/18" ];
        ap24.ports = [ "GigabitEthernet 1/0/34" ];
        ap25.ports = [ "GigabitEthernet 1/0/35" ];
        ap29.ports = [ "GigabitEthernet 1/0/36" ];
        ap30.ports = [ "GigabitEthernet 1/0/22" ];
        ap35.ports = [ "GigabitEthernet 1/0/23" ];
        ap37.ports = [ "GigabitEthernet 1/0/39" ];
        ap39.ports = [ "GigabitEthernet 1/0/17" ];
        ap40.ports = [ "GigabitEthernet 1/0/21" ];
        ap41.ports = [ "GigabitEthernet 1/0/37" ];
        ap42.ports = [ "GigabitEthernet 1/0/6" ];
        ap5.ports = [ "GigabitEthernet 1/0/7" ];
        ap51.ports = [ "GigabitEthernet 1/0/13" ];
        ap53.ports = [ "GigabitEthernet 1/0/15" ];
        ap54.ports = [ "GigabitEthernet 1/0/38" ];
        ap55.ports = [ "GigabitEthernet 1/0/19" ];
        ap56.ports = [ "GigabitEthernet 1/0/9" ];
        mgmt.ports = [
          "GigabitEthernet1/0/1"
          # server3
          "GigabitEthernet1/0/41"
          # server1
          "GigabitEthernet1/0/42"
          "GigabitEthernet1/0/43"
          # server5
          "GigabitEthernet1/0/44"
          # server6
          "GigabitEthernet1/0/45"
          # server7
          "GigabitEthernet1/0/46"
          # server8
          "GigabitEthernet1/0/47"
          # server9
          "GigabitEthernet1/0/48"
        ];
        priv1.ports = [ "GigabitEthernet 1/0/3" ];
        priv19.ports = [ "GigabitEthernet 1/0/40" ];
        priv2.ports = [ "GigabitEthernet 1/0/4" ];
        priv24.ports = [ "GigabitEthernet 1/0/14" "GigabitEthernet 1/0/16" ];
        priv3.ports = [ "GigabitEthernet 1/0/5" ];
        pub.ports = [
          "GigabitEthernet 1/0/11"
          "GigabitEthernet 1/0/20"
          "GigabitEthernet 1/0/24"
        ];
        server3 = {
          group = "1";
          ports = [ "GigabitEthernet1/0/30" "GigabitEthernet1/0/31" ];
        };
        server9 = {
          group = "3";
          ports = [
            "GigabitEthernet1/0/2"
            "GigabitEthernet1/0/29"
            "GigabitEthernet1/0/32"
          ];
        };
        switch-b1 = {
          group = "2";
          ports = [
            "TenGigabitEthernet 1/1/1"
            "GigabitEthernet 1/0/25"
            "GigabitEthernet 1/0/26"
            "GigabitEthernet 1/0/27"
            "GigabitEthernet 1/0/28"
          ];
        };
      };
    };

    switch-c1 = {
      role = "switch";
      model = "HP-procurve-2824";
      location = "Turm C Keller, bei Kabelanschluessen";
      interfaces = { mgmt.type = "phys"; };

      links = {
        # Saal A: durch dummen PoE-Switch mit Aggregation an ap44-50,52 + switch-a1
        switch-a2 = {
          group = "1";
          ports = [ "15-16" ];
        };
        switch-b1 = {
          group = "2";
          ports = [ "21-24" ];
        };
        switch-dach.ports = [ "6" ];
        # Vodafone Modems
        up1.ports = [ "1" ];
        up2.ports = [ "2" ];
        # DSI
        up4.ports = [ "4" ];
        # Turm C APs
        ap17.ports = [ "19" ];
        ap19.ports = [ "17" ];
        ap26.ports = [ "18" ];
        ap38.ports = [ "7" ];
        # Iso nets
        iso1.ports = [ "9" ];
        iso2.ports = [ "10" ];
        iso3.ports = [ "11" ];
        iso4.ports = [ "12" ];
        iso5.ports = [ "13" ];
        iso6.ports = [ "14" ];
        # Saal Foyer
        priv25.ports = [ "20" ];
      };
    };

    switch-c3d2-main = {
      role = "switch";
      model = "HP-procurve-2824";
      location = "C3D2";
      interfaces = { mgmt.type = "phys"; };

      links = {
        mgmt.ports = [ "1" ];
        switch-b1 = {
          group = "1";
          ports = [ "21-24" ];
        };
        # Kammer
        ap2.ports = [ "3" ];
        # Decke
        ap31.ports = [ "2" ];
        # Fenster
        ap33.ports = [ "5" ];
        c3d2.ports = [ "8-20" ];
        # Testing
        ap-test1.ports = [ "4" ];
        bmx.ports = [ "7" ];
        # tmp Datenspuren: VOC
        iso4.ports = [ "6" ];
      };
    };

    switch-d1 = {
      role = "switch";
      model = "TL-SG3210";
      location = "Turm D Elektroraum";
      interfaces = { mgmt.type = "phys"; };

      links = {
        switch-b1 = {
          group = "1";
          ports = [ "1" ];
        };
        switch-d2.ports = [ "3" ];

        # Turm D APs
        ap7.ports = [ "8" ];
        ap9.ports = [ "5" ];
        ap10.ports = [ "4" ];
        ap12.ports = [ "7" ];
        ap22.ports = [ "2" ];
      };
    };

    switch-d2 = {
      role = "switch";
      model = "dumb";
      location = "Turm D Durchgang 1. Etage";

      links = {
        switch-d1 = {
          group = "1";
          ports = [ "1" ];
        };
        ap3.ports = [ "1" ];
        ap59.ports = [ "2" ];
      };
    };

    switch-dach = {
      role = "switch";
      model = "HP-procurve-2824";
      location = "Dach";
      interfaces = { mgmt.type = "phys"; };

      links = {
        mgmt.ports = [ "1" ];
        switch-c1.ports = [ "24" ];
        # Freifunk nodes
        bmx.ports = [ "12,14,16" ];
        # radiobert
        serv.ports = [ "7" ];
        # Starlink
        up3.ports = [ "3" ];
        # unifiac-mesh
        ap57.ports = [ "10" ];
        # dump-dvb traffic-stop-box
        c3d2.ports = [ "20" ];
      };
    };
  };
}

